@@ -159,9 +159,12 @@ class CoreMixin:
         """Build record from JSON data (already loaded as dictionary)."""
         return cls.from_dict({k: _load(v) for k, v in data.items()})
 
-    def to_json(self, join: bool = False) -> Dict[str, __VT]:
+    def to_json(self, pop: List[str] = None, join: bool = False) -> Dict[str, __VT]:
         """Convert record values into JSON formatted types."""
         data = {k: _dump(v) for k, v in self.to_dict().items()}
+        if pop is not None:
+            for field in pop:
+                data.pop(field)
         if join is True:
             for name in self.relationships:
                 record = getattr(self, name)
@@ -184,13 +187,20 @@ class CoreMixin:
     @classmethod
     def add(cls: Type[Base], data: dict, session: _Session = None) -> Base:
         """Add record from existing `data`, return constructed record."""
+        record, = cls.add_all([data, ], session=session)
+        return record
+
+    @classmethod
+    def add_all(cls: Type[Base], data: List[dict], session: _Session = None) -> List[Base]:
+        """Add list of new records to the database and return constructed records."""
         session = session or _Session()
         try:
-            record = cls.from_dict(data)
-            session.add(record)
+            records = [cls.from_dict(record) for record in data]
+            session.add_all(records)
             session.commit()
-            log.info(f'Added {cls.__tablename__} ({record.id})')
-            return record
+            for record in records:
+                log.info(f'Added {cls.__tablename__} ({record.id})')
+            return records
         except (IntegrityError, DatabaseError):
             session.rollback()
             raise
@@ -849,7 +859,7 @@ class Source(Base, CoreMixin):
         try:
             return Source.from_name(source_name)
         except Source.NotFound:
-            return Source.add({'type_id': SourceType.from_name('Observer').id,
+            return Source.add({'type_id': SourceType.from_name('observer').id,
                                'user_id': user_id, 'facility_id': facility_id, 'name': source_name,
                                'description': f'Observer (alias={user.alias}, facility={facility.name})'})
 
@@ -892,13 +902,13 @@ class Observation(Base, CoreMixin):
     def with_object(cls, object_id: int, session: _Session = None) -> List[Observation]:
         """All observations with `object_id`."""
         session = session or _Session()
-        return session.query(cls).filter(cls.object_id == object_id).all()
+        return session.query(cls).order_by(cls.id).filter(cls.object_id == object_id).all()
 
     @classmethod
     def with_source(cls, source_id: int, session: _Session = None) -> List[Observation]:
         """All observations with `source_id`."""
         session = session or _Session()
-        return session.query(cls).filter(cls.source_id == source_id).all()
+        return session.query(cls).order_by(cls.id).filter(cls.source_id == source_id).all()
 
 
 # indices for observation table
@@ -969,6 +979,11 @@ class FileType(Base, CoreMixin):
         except NoResultFound as error:
             raise FileType.NotFound(f'No file_type with name={name}') from error
 
+    @classmethod
+    def all_names(cls) -> List[str]:
+        """All names of currently available file_type.name values."""
+        return [file_type.name for file_type in cls.query().all()]
+
 
 class File(Base, CoreMixin):
     """File table."""
@@ -1059,11 +1074,7 @@ class RecommendationGroup(Base, CoreMixin):
     @classmethod
     def new(cls, session: _Session = None) -> RecommendationGroup:
         """Create and return a new recommendation group."""
-        session = session or _Session()
-        group = cls()
-        session.add(group)
-        session.commit()
-        return group
+        return cls.add({}, session=session)
 
     @classmethod
     def latest(cls, session: _Session = None) -> RecommendationGroup:
